@@ -96,6 +96,7 @@
            #:table-comment
            #:table-storage-parameter-list
            #:table-tablespace
+           #:table-row-count-estimate
            #:table-field-list
            #:table-column-list
            #:table-index-list
@@ -913,7 +914,8 @@
            #:lisp-code-for-loading-from-dbf
            #:lisp-code-for-loading-from-ixf
            #:lisp-code-for-loading-from-sqlite
-           #:lisp-code-for-loading-from-mssql))
+           #:lisp-code-for-loading-from-mssql
+           #:lisp-code-for-loading-from-pgsql))
 
 
 ;;
