@@ -71,8 +71,8 @@
 (defrule option-fields-not-enclosed (and kw-fields kw-not kw-enclosed)
   (:constant (cons :quote nil)))
 
-(defrule quote-quote     "double-quote"   (:constant "\"\""))
-(defrule backslash-quote "backslash-quote" (:constant "\\\""))
+(defrule quote-quote     "double-quote"    (:constant #(#\" #\")))
+(defrule backslash-quote "backslash-quote" (:constant #(#\\ #\")))
 (defrule escaped-quote-name    (or quote-quote backslash-quote))
 (defrule escaped-quote-literal (or (and #\" #\") (and #\\ #\")) (:text t))
 (defrule escaped-quote         (or escaped-quote-literal
@@ -134,7 +134,8 @@
                         option-fields-terminated-by
                         option-trim-unquoted-blanks
                         option-keep-unquoted-blanks
-                        option-csv-escape-mode))
+                        option-csv-escape-mode
+                        option-null-if))
 
 (defrule csv-options (and kw-with
                              (and csv-option (* (and comma csv-option))))
@@ -231,11 +232,6 @@
     (destructuring-bind (field1 fields) source
       (list* field1 fields))))
 
-(defrule open-paren (and ignore-whitespace #\( ignore-whitespace)
-  (:constant :open-paren))
-(defrule close-paren (and ignore-whitespace #\) ignore-whitespace)
-  (:constant :close-paren))
-
 (defrule having-fields (and kw-having kw-fields) (:constant nil))
 
 (defrule csv-source-field-list (and (? having-fields)
@@ -434,26 +430,35 @@
        (progn
          ,(sql-code-block pg-db-conn :pre before "before load")
 
-         (let ((on-error-stop             (getf ',options :on-error-stop))
-               (truncate                  (getf ',options :truncate))
-               (disable-triggers          (getf ',options :disable-triggers))
-               (drop-indexes              (getf ',options :drop-indexes))
-               (max-parallel-create-index (getf ',options :max-parallel-create-index))
-               (source
-                (make-instance 'copy-csv
-                               :target-db  ,pg-db-conn
-                               :source     source-db
-                               :target     (create-table ',target-table-name)
-                               :encoding   ,encoding
-                               :fields    ',fields
-                               :columns   ',columns
-                               ,@(remove-batch-control-option
-                                  options :extras '(:worker-count
-                                                    :concurrency
-                                                    :truncate
-                                                    :drop-indexes
-                                                    :disable-triggers
-                                                    :max-parallel-create-index)))))
+         (let* ((on-error-stop             (getf ',options :on-error-stop))
+                (truncate                  (getf ',options :truncate))
+                (disable-triggers          (getf ',options :disable-triggers))
+                (drop-indexes              (getf ',options :drop-indexes))
+                (max-parallel-create-index (getf ',options :max-parallel-create-index))
+                (fields
+                 ',(let ((null-as (getf options :null-as)))
+                     (if null-as
+                         (mapcar (lambda (field)
+                                   (if (member :null-as field) field
+                                       (append field (list :null-as null-as))))
+                                 fields)
+                         fields)))
+                (source
+                 (make-instance 'copy-csv
+                                :target-db  ,pg-db-conn
+                                :source     source-db
+                                :target     (create-table ',target-table-name)
+                                :encoding   ,encoding
+                                :fields    fields
+                                :columns   ',columns
+                                ,@(remove-batch-control-option
+                                   options :extras '(:null-as
+                                                     :worker-count
+                                                     :concurrency
+                                                     :truncate
+                                                     :drop-indexes
+                                                     :disable-triggers
+                                                     :max-parallel-create-index)))))
            (copy-database source
                           ,@ (when worker-count
                                (list :worker-count worker-count))
