@@ -64,7 +64,8 @@
 
     (:source (:type "smalldatetime") :target (:type "timestamptz"))
     (:source (:type "datetime") :target (:type "timestamptz"))
-    (:source (:type "datetime2") :target (:type "timestamptz")))
+    (:source (:type "datetime2") :target (:type "timestamptz"))
+    (:source (:type "datetimeoffset") :target (:type "timestamptz")))
   "Data Type Casting to migrate from MSSQL to PostgreSQL")
 
 ;;;
